# $Id: install.py,v 1.3 2002/05/28 09:01:56 gitte Exp $
# $Source: /usr/local/cvs_root/MyMediaManager/Extensions/install.py,v $
__version__ = "$Revision: 1.3 $"[11:-2]

from Products.CMFCore.TypesTool import ContentFactoryMetadata
from Products.CMFCore.DirectoryView import addDirectoryViews, createDirectoryView
from Products.CMFCore.utils import getToolByName, minimalpath
#from Products.CMFBoringProduct import CMFBoringContent, boring_globals
from Products.MyMediaManager import mmm_globals, Clip, MasterFile, MediaLiveEvent, Medianet, MediaShow, ServerLogic, LiveServerLogic, SubEvent
from Products.ExternalMethod import ExternalMethod
from App.Common import package_home
from cStringIO import StringIO
import string

out = StringIO()

type_classes = (Clip, MasterFile, MediaLiveEvent, Medianet, MediaShow, ServerLogic, LiveServerLogic, SubEvent)

def registerType(self, fti):
    """
        Register type defined in fti in the types tool
    """
    typestool = getToolByName(self, 'portal_types')
    if fti['id'] not in typestool.objectIds():
        cfm = apply(ContentFactoryMetadata, (), fti)
        typestool._setObject(fti['id'], cfm)
        out.write('Registered %s with the types tool\n' % fti['id'])
    else:
        out.write('Object "%s" already existed in the types tool\n' % (fti['id']))

def unregisterType(self, type):
    """
        Un-Register type in the types tool
    """
    typestool = getToolByName(self, 'portal_types')
    if type in typestool.objectIds():
        typestool._delObject(type)
        out.write('Un-Registered %s with the types tool\n' % type)
    else:
        out.write('Object "%s" did not exist in the types tool\n' % type)

def removeSkin(self, skinname):
    """
    Remove a skin from portal_skins
    """
    skinstool = getToolByName(self, 'portal_skins')
    skins = skinstool.getSkinSelections()
    for skin in skins:
        path = skinstool.getSkinPath(skin)
        path = map(string.strip, string.split(path,','))
        if skinname in path:
            path.remove(skinname)
            path = string.join(path, ', ')
            # addSkinSelection will replace existing skins as well.
            skinstool.addSkinSelection(skin, path)
            out.write("Removed %s from %s skin\n" % (skinname, skin))

    if skinname in skinstool.objectIds():
        skinstool._delObject(skinname)
        out.write('Removed %s from the skinstool\n' % skinname)

def install(self):
    """Register all MMMCore components with the necessary tools"""
    out.write('MyMediaManager Installation\n')
    out.write('===========================\n\n')
    skinstool = getToolByName(self, 'portal_skins')
    portalroot = getToolByName(self, 'portal_url').getPortalObject()
    portalcatalog = getToolByName(self, 'portal_catalog')

    #type_classes = (Clip, Encoder, MasterFile, MediaLiveEvent, Medianet, MediaShow, ServerLogic, LiveServerLogic, SubEvent)
    for c in type_classes:
        t = c.factory_type_information
        if type(t) == type(()):
            for fti in t:
                registerType(self, fti)
        else:
            registerType(self, t)


    if not 'start_date' in portalcatalog.Indexes.objectIds():
        portalcatalog.addIndex('start_date', 'FieldIndex')
        out.write('Added start_date as FieldIndex\n')
    else:
        out.write('start_date already exists as FieldIndex\n')

    if not 'end_date' in portalcatalog.Indexes.objectIds():
        portalcatalog.addIndex('end_date', 'FieldIndex')
        out.write('Added end_date as FieldIndex\n')
    else:
        out.write('end_date already exists as FieldIndex\n')

    if not 'portal_mediamanager' in portalroot.objectIds():
        portalroot.manage_addProduct['MyMediaManager'].manage_addTool('Media Manager Tool', None)
        out.write('Created Media Manager Tool\n')
    else:
        out.write('Media Manager Tool already exists\n')
    if not 'medianet' in portalroot.objectIds():
        #portalroot.manage_addProduct['MyMediaManager'].manage_addMedianet('medianet', 'Media Manager Medianet')
        portalroot.invokeFactory(id='medianet', type_name='Medianet')
        out.write('Created medianet\n')
        medianet = getattr(portalroot, 'medianet')
        medianet.invokeFactory(id='OnDemand_server', type_name='OnDemand Server')
        ondemand = getattr(medianet, 'OnDemand_server')
        ondemand.edit(title='Default On Demand Server', servertype='real', protocol='rtsp', host='localhost', extension='.rm')
        out.write('Created default on demand server\n')

        medianet.invokeFactory(id='Live_server', type_name='Live Server')
        live = getattr(medianet, 'Live_server')
        live.edit(title='Default Live Server', servertype='real', protocol='rtsp', host='localhost', extension='.rm')
        out.write('Created default on live server\n')
    else:
        out.write('Medianet already exists\n')
    if not 'ftp_out' in portalroot.objectIds():
        i=ExternalMethod.ExternalMethod('ftp_out','FTP out of Zope','MyMediaManager.ftpme','ftp')
        portalroot._setObject('ftp_out',i)
        #portalroot.manage_addProduct['ExternalMethod'].manage_addExternalMethod('ftpout','FTP out from Zope','MyMediaManager.ftpme','ftp')
        out.write('Created FTP method\n')
    else:
        out.write('FTP method already exists\n')

    if not 'transitions' in portalroot.objectIds():
        i = ExternalMethod.ExternalMethod('transitions', 'Get transitions from portal_workflow', 'MyMediaManager.utils', 'getTransitions')
        portalroot._setObject('transitions', i)
        out.write('Created transitions method\n')
    else:
        out.write('transitions method already existed\n')

    # Setup the skins
    if 'mmm' not in skinstool.objectIds():
        # We need to add Filesystem Directory Views for any directories
        # in our skins/ directory.  These directories should already be
        # configured.
        fp = minimalpath("%s/zpt_skins" % package_home(mmm_globals))
        createDirectoryView(skinstool, fp, 'mmm')
        #addDirectoryViews(skinstool, 'zpt_skins', fp)
        out.write("Added 'mmm' directory view to portal_skins\n")
    else:
        out.write("'mmm' directory view already exists in portal_skins\n")
    # Now we need to go through the skin configurations and insert
    # 'CMFBoringContent' into the configurations.  Preferably, this
    # should be right before where 'content' is placed.  Otherwise, we
    # append it to the end.
    skins = skinstool.getSkinSelections()
    for skin in skins:
        path = skinstool.getSkinPath(skin)
        path = map(string.strip, string.split(path,','))
        if 'mmm' not in path:
            try: path.insert(path.index('content'), 'mmm')
            except ValueError:
                path.append('mmm')

            path = string.join(path, ', ')
            # addSkinSelection will replace existing skins as well.
            skinstool.addSkinSelection(skin, path)
            out.write("Added 'mmm' to %s skin\n" % skin)
        else:
            out.write("Skipping %s skin, 'mmm' is already set up\n" % (skin))

    return out.getvalue()

def uninstall(self):
    """
    Remove skins, types and special objects
    """
    out.write('MyMediaManager Un-Installation\n')
    out.write('===========================\n\n')
    portalroot = getToolByName(self, 'portal_url').getPortalObject()
    for c in type_classes:
        t = c.factory_type_information
        if type(t) == type(()):
            for fti in t:
                unregisterType(self, fti['id'])
        else:
            unregisterType(self, t['id'])

    removeSkin(self, 'mmm')

    if 'portal_mediamanager' in portalroot.objectIds():
        portalroot._delObject('portal_mediamanager')
        out.write('Removed Media Manager Tool\n')

    if 'ftp_out' in portalroot.objectIds():
        portalroot._delObject('ftp_out')
        out.write('Removed FTP method\n')

    if 'transitions' in portalroot.objectIds():
        portalroot._delObject('transitions')
        out.write('Removed transitions method\n')

    if 'medianet' in portalroot.objectIds():
        portalroot._delObject('medianet')
        out.write('Removed Medianet\n')

    return out.getvalue()
