# $Id: MMMToolBox.py,v 1.48 2002/03/10 22:00:28 thomas Exp $
# $Source: /usr/local/cvs_root/MyMediaManager/MMMToolBox.py,v $
__version__ = "$Revision: 1.48 $"[11:-2]

import os, urllib
from Globals import InitializeClass, Persistent, package_home
from OFS.SimpleItem import SimpleItem
from AccessControl import ClassSecurityInfo
from Products.CMFCore.utils import getToolByName, UniqueObject
from Products.CMFCore.CMFCorePermissions import View
from Products.CMFCore.CMFCorePermissions import ManageProperties
from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
from Products.CMFCore.PortalContent import PortalContent
from Products.CMFCore.WorkflowCore import WorkflowAction
from Products.PageTemplates import PageTemplateFile

# Import permission names
from Products.CMFCore import CMFCorePermissions

_zptdir = os.path.join( package_home( globals() ), 'www' )


"""
factory_type_information = {
      'id': 'Toolbox',
      'meta_type': 'Media Manager Toolbox',
      'description': 'Use Media Manager Toolbox to add new content',
      'product': 'MyMediaManager',
      'icon': '/misc_/CMFCore/tool.gif',
      'factory': 'addMMMToolBox',
      'filter_content_types': 1,
      'immediate_view': 'toolbox_edit_form',
      'actions':
            ({'name': 'View',
              'action': 'toolbox_view',
              'permissions': ('View',),
              'category': 'object'},
              {'name': 'Edit',
               'action': 'toolbox_edit_form',
               'permissions': ('Modify portal content',),
               'category': 'object'})
       }
"""
def addMMMToolBox(self, id, REQUEST=None):
    """Create an empty MMMToolBox"""
    mmmtoolbox_object = MMMToolBox(id)
    self._setObject(id, mmmtoolbox_object)

class MMMToolBox(UniqueObject, SimpleItem):
    """doc string"""

    meta_type='MMM ToolBox'
    id = 'portal_toolbox'


    security = ClassSecurityInfo()
    security.declareObjectPublic()

    manage_options = (({ 'label' : 'Configuration'
                     , 'action' : 'manage_setTypes'
                     },) +
                     SimpleItem.manage_options +
                     ({ 'label' : 'Overview', 'action' : 'manage_overview' }
                     ,
                     ))

    #
    #   ZMI methods
    #
    security.declareProtected( CMFCorePermissions.ManagePortal
                             , 'manage_overview' )
    manage_overview = PageTemplateFile.PageTemplateFile( 'explainToolbox', _zptdir )

    security.declareProtected(CMFCorePermissions.ManagePortal, 'manage_setTypes')
    manage_setTypes = PageTemplateFile.PageTemplateFile('toolboxSetTypes', _zptdir )

    #security.declarePublic('index_html')
    #def index_html( self ):
    #    """
    #    call the object
    #    """
    #    return self.__call__()

    #security.declarePublic('getId')
    #def getId( self ):
    #    """
    #    """
    #    return self.id

    security.declareProtected(ManageProperties, 'manage_setGlobalTypes')
    def manage_setGlobalTypes(self, allowed_content_types=None, REQUEST=None):
        """Change the tools properties """
        if allowed_content_types is not None:
            self._allowed_content_types = allowed_content_types
        if REQUEST is not None:
            return self.manage_setTypes(
                self, REQUEST, manage_tabs_message='Properties changed.')

    security.declareProtected(ManageProperties, 'setTypes')
    def setTypes(self, allowed_content_types=None, REQUEST=None):
        """Change the instance's properties """
        home = self._getHomeFolder()
        if allowed_content_types is not None:
            home.allowed_content_types = allowed_content_types
        if REQUEST is not None:
            REQUEST.RESPONSE.redirect("%s/toolbox_edit_form?portal_status_message=%s" % (self.absolute_url(), "Saved"))

    def _getHomeFolder( self ):
        # get the portal type tool
        portal_types = getToolByName(self, 'portal_types')

        # get the portal membership tool
        portal_membership = getToolByName(self, 'portal_membership')

        # get the home folder object (check if the user is allowed to view it)
        home = portal_membership.getHomeFolder(verifyPermission=1)
        return home

    security.declarePublic('listTypes')
    def listTypes( self ):
        """
            List type info objects for types which can be added in
            a home folder.
        """
        result = []

        home = self._getHomeFolder()

        if home:
            # get a type info object for the home folder
            portal_types = getToolByName(self, 'portal_types')
            myType = portal_types.getTypeInfo(home)

            # if there exists a type info object
            if myType is not None:
                # check if the folder allows creation of the types in the types tool
                for contentType in portal_types.listTypeInfo():
                    if myType.allowType( contentType.Type() ) and self.allowGlobalType( contentType.Type() ):
                        result.append( contentType )
            else: # use all types
                result = portal_types.listTypeInfo()

            return filter( lambda typ, container=home:
                            typ.isConstructionAllowed( container )
                        , result )
        else:
            raise "Couldn't get home folder object"

    security.declarePublic('listFilteredTypes')
    def listFilteredTypes( self ):
        """
            List type info objects for types which can be added in
            a home folder.
        """
        home = self._getHomeFolder()
        if not hasattr(home, 'allowed_content_types'):
            return self.listTypes()
        result = []
        for contentType in self.listTypes():
            if self.allowType( contentType.Type() ):
                result.append( contentType )
        return result


    security.declarePublic('getNewId')
    def getNewId( self ):
        """
        return a new unique ID
        """
        mm = getToolByName(self, 'portal_mediamanager')
        return mm.getUniqueID()

    security.declarePublic('allowType')
    def allowType( self, type ):
        """
        return true if this toolbox should contain type
        """
        home = self._getHomeFolder()
        if not hasattr(home, 'allowed_content_types'):
            home.allowed_content_types = ()

        return type in home.allowed_content_types

    security.declarePublic('allowGlobalType')
    def allowGlobalType( self, type ):
        """
        return true if this toolbox should contain type
        """
        if not hasattr(self, '_allowed_content_types'):
            self._allowed_content_types = ()

        return type in self._allowed_content_types



InitializeClass(MMMToolBox)

