##############################################################################
# 
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
# 
# Copyright (c) Digital Creations.  All rights reserved.
# 
# This license has been certified as Open Source(tm).
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
#
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
# 
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
# 
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
# 
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
#
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
# 
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
#
#
# Disclaimer
#
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
#
#
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
#
##############################################################################
"""
"""

ADD_FOLDERS_PERMISSION = 'Add portal folders'

#MMMCore
import Medianet
import MasterFile
import MediaShow
import MediaLiveEvent
import ServerLogic
import LiveServerLogic
import Clip
import SubEvent
import MediaManagerTool
from Products.CMFCore.FSDTMLMethod import FSDTMLMethod

#CMF
from Products.CMFCore import utils
from Products.CMFCore.DirectoryView import registerFileExtension, registerDirectory

contentClasses = (  Medianet.Medianet
                  , MasterFile.MasterFile
                  , MediaShow.MediaShow
                  , MediaLiveEvent.MediaLiveEvent
                  , ServerLogic.ServerLogic
                  , LiveServerLogic.LiveServerLogic
                  , Clip.MediaClip
                  , SubEvent.SubEvent
                    )

contentConstructors = ( Medianet.manage_addMedianet
                      , MasterFile.addMasterFile
                      , MediaShow.addMediaShow
                      , MediaLiveEvent.addMediaLiveEvent
                      , ServerLogic.addServerLogic
                      , LiveServerLogic.addLiveServerLogic
                      , Clip.addMediaClip
                      , SubEvent.addSubEvent
                        )

bases = contentClasses

tools = ( MediaManagerTool.MediaManagerTool,)
#tools = (CreditTool.PaymentTool, )

import sys
this_module = sys.modules[ __name__ ]

z_bases = utils.initializeBasesPhase1( bases, this_module )
z_tool_bases = utils.initializeBasesPhase1( tools, this_module )

FolderConstructorForm = ( 'manage_addMedianetForm'
                        , Medianet.manage_addMedianetForm
                        )
# This is used by a script (external method) that can be run
# to set up MMM in an existing CMF Site instance.
mmm_globals=globals()

#Make the skins availiable as DirectoryViews
registerDirectory('zpt_skins', globals())

# register javascript files as dtml methods
registerFileExtension('js', FSDTMLMethod)

def initialize( context ):

    context.registerHelp(directory='help')
    context.registerHelpTitle('Media Manager Help')

    utils.initializeBasesPhase2( z_bases, context )
    utils.initializeBasesPhase2( z_tool_bases, context )

    utils.ToolInit( 'Media Manager Tool', tools = tools,
                     product_name = 'MyMediaManager', icon='tool.gif',
                    ).initialize( context )

    utils.ContentInit( 'Media Manager Content'
                     , content_types=contentClasses
                     , permission=ADD_FOLDERS_PERMISSION
                     , extra_constructors=contentConstructors
                     , fti = ( Medianet.factory_type_information
                            + MasterFile.factory_type_information
                            + MediaShow.factory_type_information
                            + MediaLiveEvent.factory_type_information
                            + ServerLogic.factory_type_information
                            + LiveServerLogic.factory_type_information
                            + Clip.factory_type_information
                            + SubEvent.factory_type_information
                    )
                     ).initialize( context )

